summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/qsound.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/qsound.cpp')
-rw-r--r--src/devices/sound/qsound.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/devices/sound/qsound.cpp b/src/devices/sound/qsound.cpp
index 232e367f1d2..29b2661add5 100644
--- a/src/devices/sound/qsound.cpp
+++ b/src/devices/sound/qsound.cpp
@@ -207,7 +207,7 @@ void qsound_device::device_add_mconfig(machine_config &config)
void qsound_device::device_start()
{
// hope we get good synchronisation between the DSP and the sound system
- m_stream = stream_alloc_legacy(0, 2, clock() / 2 / 1248);
+ m_stream = stream_alloc(0, 2, clock() / 2 / 1248);
// save DSP communication state
save_item(NAME(m_rom_bank));
@@ -251,13 +251,13 @@ void qsound_device::device_reset()
//-------------------------------------------------
// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------
-void qsound_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
+void qsound_device::sound_stream_update(sound_stream &stream, std::vector<read_stream_view> const &inputs, std::vector<write_stream_view> &outputs)
{
- std::fill_n(outputs[0], samples, m_samples[0]);
- std::fill_n(outputs[1], samples, m_samples[1]);
+ outputs[0].fill(stream_buffer::sample_t(m_samples[0]) * (1.0 / 32768.0));
+ outputs[1].fill(stream_buffer::sample_t(m_samples[1]) * (1.0 / 32768.0));
}
@@ -251,13 +251,13 @@ void qsound_device::device_reset()
//-------------------------------------------------
-// sound_stream_update_legacy - handle a stream update
+// sound_stream_update - handle a stream update
//-------------------------------------------------